"use strict";
this.name = "taranis_one";
this.author = "Robert Todd (Roberto on Oolite Forums)";
this.copyright = "© 2006 Creative Commons: attribution, non-commercial, sharealike.";
this.description = "worldScript for the taranis mission";
this.version = "2.0";


//-------------------------------------------------------------------------------------------------------------
this.startUp = function () {
    if (missionVariables.taranis_one == "TAR1_COMPLETE" || missionVariables.taranis_one == "TAR1_FAILED") {
        this.$cleanUp();
    }
};

//-------------------------------------------------------------------------------------------------------------
this.turnStationToEntity = function (station, entity) {
	var targetVector = entity.position.subtract(station.position).direction();
	station.orientation = targetVector.rotationTo([0, 0, 1]);
}

//-------------------------------------------------------------------------------------------------------------
this.systemWillPopulate = function() {
	if (galaxyNumber === 0 && system.ID === 141) {
		var stationPos = Vector3D(157000, 37000, 28000).fromCoordinateSystem("pwm");
		system.setPopulator("taranis_station", {
			callback: function (pos) {
                if (system.countShipsWithRole("taranis") == 0) {
				    var stn = system.addShips("[taranis]", 1, pos, 0)[0];
				    worldScripts["taranis_one"].turnStationToEntity(stn, system.mainPlanet);
                }
			},
			location: "COORDINATES",
			coordinates: stationPos,
			deterministic: true
		});
	}
}

//-------------------------------------------------------------------------------------------------------------
this.missionScreenOpportunity = function () {
    if (!player.ship.docked || galaxyNumber != 0) return;
    this.missionOffers();
};

//-------------------------------------------------------------------------------------------------------------
this.missionOffers = function () {
    if (player.ship.dockedStation.isMainStation) {
        if (missionVariables.taranis_one == "TAR1_ACTIVE" && missionVariables.taranis_one_startdate + 2 < clock.days) {
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_incoming",
                music: "taranis_comms.ogg",
                choicesKey: "taranis_one_incoming2_justyes"
            }, this.choiceEvaluation
            );
        }
        if (missionVariables.taranis_one == "TAR1_DESTROYED") {
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_incoming",
                music: "taranis_comms.ogg",
                choicesKey: "taranis_one_incoming_justyes"
            }, this.choiceEvaluation
            );
        }
    } else if (system.ID == 141 && player.ship.dockedStation.name == "Taranis Corporation HQ") {
        if (!missionVariables.taranis_one && player.score > 127 && player.bounty < 5) {
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_preamble",
                choicesKey: "taranis_one_preamble_justyes",
                music: "swifts_theme.ogg"
            }, this.choiceEvaluation
            );
        }
    }
};


//-------------------------------------------------------------------------------------------------------------
this.choiceEvaluation = function (choice) {
    switch (choice) {
        case "1":
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_intro1",
                choicesKey: "taranis_one_cont1_justyes",
                music: "swifts_theme.ogg"
            }, this.choiceEvaluation
            );
            break;
        case "2":
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_intro2",
                choicesKey: "taranis_one_cont2_justyes",
                music: "swifts_theme.ogg"
            }, this.choiceEvaluation
            );
            break;
        case "3":
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_decision",
                choicesKey: "taranis_one_offer_yesno",
                music: "swifts_theme.ogg"
            }, this.choiceEvaluation
            );
            break;
        case "4":
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_accepted",
                choicesKey: "taranis_one_cont3_justyes",
                music: "swifts_theme.ogg"
            }, this.choiceEvaluation
            );
            break;
        case "5":
            missionVariables.taranis_one = "TAR1_PASSED";
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_declined"
            });
            break;
        case "6":
            missionVariables.taranis_one_startdate = clock.days;
            missionVariables.taranis_one = "TAR1_ACTIVE";
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_briefing",
                music: "swifts_theme.ogg"
            });
            mission.markSystem({ system: 111, name: "taranis" });
            player.credits += 2000;
            this.updateTimeLeft();
            break;
        case "7":
            missionVariables.taranis_one = "TAR1_COMPLETE";
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_success",
                music: "swifts_theme.ogg"
            });
            mission.setInstructionsKey(null);
            mission.unmarkSystem({ system: 111, name: "taranis" });
            player.credits += 2000;
            delete missionVariables.taranis_one_startdate;
            delete missionVariables.taranis_one_daysremaining;
            this.$cleanUp();
            break;
        case "8":
            missionVariables.taranis_one = "TAR1_FAILED";
            mission.runScreen({
                title: "Taranis one",
                screenID: "taranis",
                messageKey: "taranis_one_failure",
                music: "swifts_theme.ogg"
            });
            mission.setInstructionsKey(null);
            mission.unmarkSystem({ system: 111, name: "taranis" });
            // repay the advance fee for the mission.
            if (player.credits > 2000) player.credits -= 2000; else player.credits = 0;
            delete missionVariables.taranis_one_startdate;
            delete missionVariables.taranis_one_daysremaining;
            this.$cleanUp();
            break;

        default:
            break;
    }
};

//-------------------------------------------------------------------------------------------------------------
this.shipLaunchedFromStation = function () {
    if (missionVariables.taranis_one == "TAR1_ACTIVE") {
        this.updateTimeLeft();
    }
};

//-------------------------------------------------------------------------------------------------------------
this.shipExitedWitchspace = function () {
    if (missionVariables.taranis_one == "TAR1_ACTIVE" && !this.messagesTimer) {
        this.messagesTimer = new Timer(this, this.waitForAdjusting, 0, 2); // clock might not be valid yet.
    }
    if (missionVariables.taranis_one == "TAR1_PASSED" && Math.random() < 0.05) {
        missionVariables.taranis_one = null; // restart mission offers
    }
};

//-------------------------------------------------------------------------------------------------------------
this.waitForAdjusting = function () {
    if (clock.isAdjusting) return;
    var timePast = this.updateTimeLeft();
    if (system.ID == 111 && timePast < 3) {
        system.addShips("taranis-wolf", 1, Vector3D(127112, 20303, 662546).fromCoordinateSystem("pwm"), 0);
    }
    this.messagesTimer.stop();
    delete this.messagesTimer;
}

//-------------------------------------------------------------------------------------------------------------
this.updateTimeLeft = function () {
    var timePast = clock.days - missionVariables.taranis_one_startdate;
    switch (timePast) {
        case 0:
            missionVariables.taranis_one_daysremaining = "three days";
            break;
        case 1:
            missionVariables.taranis_one_daysremaining = "two days";
            break;
        case 2:
            missionVariables.taranis_one_daysremaining = "one day";
            break;
        default:
            // Mission ended not in time.
            mission.setInstructionsKey("mission_taranis_one_desc2");
            mission.unmarkSystem({ system: 111, name: "taranis" });
            break;
    }
    if (timePast < 3) mission.setInstructionsKey("mission_taranis_one_desc1");

    return timePast;
};

//-------------------------------------------------------------------------------------------------------------
this.$cleanUp = function () {
    delete this.missionScreenOpportunity;
    delete this.shipLaunchedFromStation;
    delete this.shipExitedWitchspace;
};
